==> soundcontrol-0.1.0.tgz: package/lib/soundcontrol.js <==
(function(){
    
    var exec = require('child_process').exec;
    var paused = false;
    var sc = {
        version: '0.1'
    };
    
    /* public methods */
    
    sc.isItunesOpen = function(callback) {
        exec("ps aux | grep -i iTunes.app", function(err,stdout,stderr){
            var lines = stdout.split('\n');
            var found = lines.length;
            
            for (var i = 0; i < lines.length; i++) {
                var trimmed = lines[i].replace(/^\s+|\s+$/g, '');;
                
                if (!trimmed || trimmed.search('iTunesHelper') !== -1 || lines[i].search('grep') !== -1) {
                    found--;
                }
            }
            
            callback(err, found > 0);
        });
    };
    
    sc.isSpotifyOpen = function(callback) {
        exec("ps aux | grep -i Spotify.app", function(err,stdout,stderr){
            var lines = stdout.split('\n');
            var found = lines.length;
            
            for (var i = 0; i < lines.length; i++) {
                var trimmed = lines[i].replace(/^\s+|\s+$/g, '');;
                
                if (!trimmed || lines[i].search('grep') !== -1) {
                    found--;
                }
            }
            
            callback(err, found > 0);
        });
    };
    
    sc.isPlaying = function(app, callback) {
        app = app || "iTunes";
        
        exec("osascript -e 'tell application \""+ app +"\" to player state as string'", function(err,stdout,stderr){
            if (stdout.trim() == "playing") {
                paused = app;
                callback(err, true);
            } else {
                callback(err, false);
            }
        });
    };
    
    sc.isSpotifyPlaying = function(callback) {
        sc.isPlaying('spotify', callback);
    };
    
    sc.isItunesPlaying = function(callback) {
        sc.isPlaying('iTunes', callback);
    };
    
    sc.pauseAll = function() {
        sc.isItunesOpen(function(err, open){
            if (!open) return;
            
            sc.isItunesPlaying(function(err, playing){
                if (!playing) {
                    sc.pause('iTunes');
                }
            });
        });
        
        sc.isSpotifyOpen(function(err, open){
            if (!open) return;
            
            sc.isSpotifyPlaying(function(err, playing){
                if (playing) {
                    sc.pause('spotify');
                }
            });
        });
    };
    
    sc.pause = function(app) {
        app = app || "iTunes";
        exec("osascript -e 'tell application \""+ app +"\" to pause';");
        paused = app;
    };
    
    sc.play = function(app) {
        app = app || "iTunes";
        exec("osascript -e 'tell application \""+ app +"\" to play';");
    };
    
    sc.stop = function(app) {
        app = app || "iTunes";
        exec("osascript -e 'tell application \""+ app +"\" to stop';");
    };
    
    sc.resume = function() {
        if (paused) {
            sc.play(paused);
            paused = false;
        }
    };
    
    module.exports = sc;
})();

==> soundcontrol-0.1.1.tgz: package/lib/soundcontrol.js <==
(function(){
    
    var exec = require('child_process').exec;
    var paused = false;
    var apps = [
        'iTunes',
        'spotify',
        'rdio'
    ];
    var sc = {
        version: '0.1'
    };
    
    /* public methods */
    
    sc.isPlaying = function(app, callback) {
        exec("osascript -e 'tell application \""+ app +"\" to player state as string'", function(err,stdout,stderr){
            if (stdout.trim() == "playing") {
                paused = app;
                callback(err, true);
            } else {
                callback(err, false);
            }
        });
    };
    
    sc.isSpotifyPlaying = function(callback) {
        sc.isPlaying('spotify', callback);
    };
    
    sc.isItunesPlaying = function(callback) {
        sc.isPlaying('iTunes', callback);
    };
    
    sc.isRdioPlaying = function(callback) {
        sc.isPlaying('rdio', callback);
    };
    
    sc.pause = function(app) {
        if (!app) return pauseAll();
        
        exec("osascript -e 'tell application \""+ app +"\" to pause';");
        paused = app;
    };
    
    sc.stop = sc.pause;
    
    sc.play = function(app) {
        exec("osascript -e 'tell application \""+ app +"\" to play';");
    };
    
    sc.resume = function() {
        if (paused) {
            sc.play(paused);
            paused = false;
        }
    };
    
    
    /* private methods */
    
    var pauseAll = function() {
        
        apps.forEach(function(app){
            
            isAppOpenMac(app, function(err, open){
                if (!open) return;
                
                sc.isPlaying(app, function(err, playing){
                    if (playing) sc.pause(app);
                });
            });
        });
    };
    
    var isAppOpenMac = function(app, callback) {
        
        exec("osascript -e 'tell application \"System Events\" to (name of processes) contains \""+ app +"\"';", function(err,stdout,stderr){
            callback(err, stdout.trim() == "true");
        });
    };
    
    module.exports = sc;
})();
